@@ -138,7 +138,7 @@ def start_runner(test_queue, runner_command_queue, runner_result_queue,
             except KeyboardInterrupt:
                 stop_flag.set()
     except Exception:
-        runner_result_queue.put(("log", ("critical", traceback.format_exc())))
+        runner_result_queue.put(("log", ("critical", {"message": traceback.format_exc()})))
         print >> sys.stderr, traceback.format_exc()
         stop_flag.set()
     finally:
@@ -149,7 +149,7 @@ def start_runner(test_queue, runner_command_queue, runner_result_queue,
 manager_count = 0
 
 
-def get_manager_number():
+def next_manager_number():
     global manager_count
     local = manager_count = manager_count + 1
     return local
@@ -190,7 +190,7 @@ class TestRunnerManager(threading.Thread):
 
         self.pause_on_unexpected = pause_on_unexpected
 
-        self.manager_number = get_manager_number()
+        self.manager_number = next_manager_number()
 
         self.command_queue = Queue()
         self.remote_queue = Queue()
@@ -219,7 +219,7 @@ class TestRunnerManager(threading.Thread):
     def run(self):
         """Main loop for the TestManager.
 
-        TestManagers generally recieve commands from their
+        TestManagers generally receive commands from their
         TestRunner updating them on the status of a test. They
         may also have a stop flag set by the main thread indicating
         that the manager should shut down the next time the event loop
@@ -273,7 +273,7 @@ class TestRunnerManager(threading.Thread):
                                 # Need to consider the unlikely case where one test causes the
                                 # runner process to repeatedly die
                                 self.logger.info("Last test did not complete, requeueing")
-                                self.requeue_test(self.test)
+                                self.requeue_test()
                             self.logger.warning(
                                 "More tests found, but runner process died, restarting")
                             self.restart_count += 1
@@ -315,7 +315,6 @@ class TestRunnerManager(threading.Thread):
             self.init_timer = threading.Timer(self.browser.init_timeout, init_failed)
             try:
                 self.init_timer.start()
-
                 self.browser.start()
                 self.start_test_runner()
             except:
@@ -347,7 +346,7 @@ class TestRunnerManager(threading.Thread):
         if self.init_fail_count < self.max_init_fails:
             self.restart_runner()
         else:
-            self.logger.critical("Test runner failed to initalise correctly; shutting down")
+            self.logger.critical("Test runner failed to initialise correctly; shutting down")
             return Stop
 
     def start_test_runner(self):
@@ -465,10 +464,7 @@ class TestRunnerManager(threading.Thread):
                                     message=result.message,
                                     expected=expected)
 
-        # Check if we crashed after getting a result
-#        if not self.browser.is_alive():
-#            logger.debug("Changing status of test %r to crash" % (test.id,))
-#            file_result.status = "CRASH"
+        # TODO: consider changing result if there is a crash dump file
 
         # Write the result of the test harness
         expected = test.expected()
@@ -538,7 +534,7 @@ class ManagerGroup(object):
         """Start all managers in the group"""
         self.logger.debug("Using %i processes" % self.size)
         self.tests_queue = tests_queue
-        for i in range(self.size):
+        for _ in range(self.size):
             manager = TestRunnerManager(self.suite_name,
                                         tests_queue,
                                         self.browser_cls,
@@ -552,10 +548,7 @@ class ManagerGroup(object):
 
     def is_alive(self):
         """Boolean indicating whether any manager in the group is still alive"""
-        for manager in self.pool:
-            if manager.is_alive():
-                return True
-        return False
+        return any(manager.is_alive() for manager in self.pool)
 
     def wait(self):
         """Wait for all the managers in the group to finish"""
@@ -569,7 +562,4 @@ class ManagerGroup(object):
         self.logger.debug("Stop flag set in ManagerGroup")
 
     def unexpected_count(self):
-        count = 0
-        for item in self.pool:
-            count += item.unexpected_count
-        return count
+        return sum(item.unexpected_count for item in self.pool)
